==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebToggleViewCancelableEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableBrowserEventArgsDetailDescriptionMetadata } from "./WebCancelableBrowserEventArgsDetailDescriptionMetadata";
import { WebToggleViewCancelableEventArgsDetailDescription } from "./WebToggleViewCancelableEventArgsDetailDescription";
/**
 * @hidden
 */
var WebToggleViewCancelableEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebToggleViewCancelableEventArgsDetailDescriptionMetadata, _super);
    function WebToggleViewCancelableEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebToggleViewCancelableEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a == null) {
            WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebToggleViewCancelableEventArgsDetailDescriptionMetadata.c(WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a);
    };
    WebToggleViewCancelableEventArgsDetailDescriptionMetadata.c = function (a) {
        WebCancelableBrowserEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ToggleViewCancelableEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
    };
    WebToggleViewCancelableEventArgsDetailDescriptionMetadata.d = function (a) {
        WebToggleViewCancelableEventArgsDetailDescriptionMetadata.b(a);
        a.ad("WebToggleViewCancelableEventArgsDetail", function () { return new WebToggleViewCancelableEventArgsDetailDescription(); });
        a.ac("WebToggleViewCancelableEventArgsDetail", WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a);
    };
    WebToggleViewCancelableEventArgsDetailDescriptionMetadata.$t = markType(WebToggleViewCancelableEventArgsDetailDescriptionMetadata, 'WebToggleViewCancelableEventArgsDetailDescriptionMetadata');
    WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a = null;
    return WebToggleViewCancelableEventArgsDetailDescriptionMetadata;
}(Base));
export { WebToggleViewCancelableEventArgsDetailDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebToggleViewCancelableEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebToggleViewCancelableEventArgsDetailDescription } from "./WebToggleViewCancelableEventArgsDetailDescription";
/**
 * @hidden
 */
var WebToggleViewCancelableEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebToggleViewCancelableEventArgsDetailDescriptionMetadata, _super);
    function WebToggleViewCancelableEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebToggleViewCancelableEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a == null) {
            WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebToggleViewCancelableEventArgsDetailDescriptionMetadata.c(WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a);
    };
    WebToggleViewCancelableEventArgsDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ToggleViewCancelableEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Id", "String");
    };
    WebToggleViewCancelableEventArgsDetailDescriptionMetadata.d = function (a) {
        WebToggleViewCancelableEventArgsDetailDescriptionMetadata.b(a);
        a.ae("WebToggleViewCancelableEventArgsDetail", function () { return new WebToggleViewCancelableEventArgsDetailDescription(); });
        a.ad("WebToggleViewCancelableEventArgsDetail", WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a);
    };
    WebToggleViewCancelableEventArgsDetailDescriptionMetadata.$t = markType(WebToggleViewCancelableEventArgsDetailDescriptionMetadata, 'WebToggleViewCancelableEventArgsDetailDescriptionMetadata');
    WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a = null;
    return WebToggleViewCancelableEventArgsDetailDescriptionMetadata;
}(Base));
export { WebToggleViewCancelableEventArgsDetailDescriptionMetadata };
